pecos.slr
=========

.. automodule:: pecos.slr



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.slr.block
   pecos.slr.cond_block
   pecos.slr.cops
   pecos.slr.fund
   pecos.slr.gen_codes
   pecos.slr.main
   pecos.slr.misc
   pecos.slr.util
   pecos.slr.vars
